CookieOptions class

Constructors

CookieOptions({String? path, String? domain, bool? httpOnly, bool? secure, int? maxAge, DateTime? expires, String? sameSite})
const

Properties

domain String?
final
expires DateTime?
final
hashCode int
The hash code for this object.
no setterinherited
httpOnly bool?
final
maxAge int?
final
path String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sameSite String?
final
secure bool?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited