headers property

Map<String, String?>? headers
final

Header overrides applied after the original headers are forwarded.

A null value removes that header from the upstream request.

Implementation

final Map<String, String?>? headers;