hit abstract method
Records a request for key within window and returns the new state.
Implementation
FutureOr<RateLimitHit> hit(String key, Duration window);
Records a request for key within window and returns the new state.
FutureOr<RateLimitHit> hit(String key, Duration window);