route library
Functions
-
basePath(
Context c) → String? - Returns the resolved base path for the current request.
-
baseRoutePath(
Context c) → String? - Returns the group prefix pattern of the matched route.
-
matchedRoutes(
Context c) → List< RouteSpec> - Returns all routes that matched the current request — including path-based middleware routes and the matched handler route.
-
routePath(
Context c) → String? - Returns the registered route pattern of the matched handler.