SessionController class

Constructors

SessionController(Context _c, String _secret, int _duration, String _cookieName)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

delete() → void
Clears the session and deletes the cookie.
get() Map<String, dynamic>?
Returns the current session data, or null if no active session.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
update(Map<String, dynamic> data) Future<void>
Replaces the session data and writes the signed cookie to the response.

Operators

operator ==(Object other) bool
The equality operator.
inherited