DartoSSEWriter class

Writer for Server-Sent Events via streamSSE.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onAbort(void callback()) → void
Registers callback to be called when the client disconnects.
sleep(Duration duration) Future<void>
Pauses the event stream for duration.
toString() String
A string representation of this object.
inherited
writeSSE(SseEvent event) Future<void>
Sends a structured SSE event to the client.

Operators

operator ==(Object other) bool
The equality operator.
inherited