DartoStreamWriter class

Writer for raw binary streaming via stream.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onAbort(void callback()) → void
Registers callback to be called when the client disconnects.
pipe(Stream<List<int>> source) Future<void>
Pipes a binary source stream into the response.
toString() String
A string representation of this object.
inherited
write(List<int> chunk) Future<void>
Sends a binary chunk immediately.

Operators

operator ==(Object other) bool
The equality operator.
inherited