onAbort method
void
onAbort(
- void callback()
Registers callback to be called when the client disconnects.
Implementation
void onAbort(void Function() callback) => _onAbortCallback = callback;
Registers callback to be called when the client disconnects.
void onAbort(void Function() callback) => _onAbortCallback = callback;