DartoTextStreamWriter class

Writer for plain-text streaming via streamText.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pipe(Stream<String> source) Future<void>
Pipes a text source stream into the response.
sleep(Duration duration) Future<void>
Pauses the stream for duration.
toString() String
A string representation of this object.
inherited
write(String text) Future<void>
Sends text without a trailing newline.
writeln(String text) Future<void>
Sends text followed by a newline character.

Operators

operator ==(Object other) bool
The equality operator.
inherited