- Available extensions
Properties
- baseUrl → String
-
no setter
- body → Future
-
no setter
-
context
→ Map<
String, dynamic> -
no setter
-
no setter
-
file
↔ Map<
String, dynamic> ? -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- headers → DartoHeader
-
no setter
- host → String
-
no setter
- hostname → String
-
no setter
- ip → String
-
no setter
-
ips
→ List<
String> -
no setter
- log → Logger
-
Available on Request, provided by the RequestExtensions extension
no setter - method → String
-
no setter
- onResponseFinished ↔ void Function()?
-
getter/setter pair
- originalUrl → String
-
no setter
-
param
→ Map<
String, String> -
no setter
- path → String
-
no setter
- protocol → String
-
no setter
-
query
→ Map<
String, String> -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
session
→ Map<
String, dynamic> -
no setter
- timedOut ↔ bool
-
getter/setter pair
- timeout ↔ int?
-
getter/setter pair
- uri → Uri
-
no setter
Methods
-
arrayBuffer(
) → Future< ByteBuffer> -
blob(
) → Future< Uint8List> -
bodyParse<
T> (T parser(dynamic body)) → Future< T> -
cast<
T> () → Stream< List< int> > -
formData(
) → Future -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
params(
) → List< String?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited