RateLimitHit class

State returned by a RateLimitStore after recording a request.

Constructors

RateLimitHit(int count, DateTime resetAt)
const

Properties

count int
Requests counted in the current window (including this one).
final
hashCode int
The hash code for this object.
no setterinherited
resetAt DateTime
When the current window resets.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited