RateLimitStore class abstract
Backing store for rateLimit.
The default is MemoryRateLimitStore (process-local). Implement this to
back the limiter with a shared store (Redis/Memcached) for horizontally
scaled deployments — see the darto_rate_limit plugin on the roadmap.
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
hit(
String key, Duration window) → FutureOr< RateLimitHit> -
Records a request for
keywithinwindowand returns the new state. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reset(
String key) → FutureOr< void> -
Clears the counter for
key. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited